# About the Instafeed Module

The Instafeed module integrates the instafeed.js library (https://instafeedjs.com/#/) into your Drupal website, allowing you to display an Instagram feed seamlessly. Additionally, it provides functionality to automatically refresh the Instagram access token before it expires, ensuring uninterrupted access to your Instagram content. The Instagram feed is displayed using customizable blocks that can be placed in any region of your website.

## Preparation

For this module to work, you need to create a Facebook app with Instagram Basic Display. Follow the guide at https://developers.facebook.com/docs/instagram-basic-display-api/getting-started/ for detailed instructions.

### Quick Rundown of Steps:

- Visit the Facebook Developers page (https://developers.facebook.com/) and log in.
- Create a Facebook app and choose the Consumer app type.
- Add the site URL (Site, Redirect, and Callback URL) to the app settings.
- Create the Instagram Basic Display app within the Facebook app.
- Add Instagram Tester with the role "Instagram Testers" and select the Instagram account for testing.
- Authorize the app on the test user's Instagram account and accept the tester invite.
- Generate an access token for the test user in the Facebook/Instagram app (This step must be verified once more on the test user's Instagram account).
- Copy and securely store the access token for later use in the Instafeed module settings.

## Installation

This module requires the external library instafeed.js (https://github.com/stevenschobert/instafeed.js/releases/tag/v2.0.0) and must be installed so the required js file have the following url from drupal-root `/libraries/instafeed.js/dist/instafeed.min.js`. If you add this library after module installation, a warning will be displayed.

Install the module as you would with any other Drupal module. Navigate to the module settings page and paste the Instagram access token obtained earlier. Finally, go to the block layout page and add the Instafeed block to the desired region of your website. Your Instagram feed should now be visible on your site. If you do not see it, try clearing the site cache.

## Configuration (For Production Environments Only)

To enable automatic access token refreshing, modify the settings.php file with the following code. Ensure the URL provided does not include the protocol (http/https) and does not end with a slash.

```php
$settings['production_url'] = 'production-url.com';
```

When this setting is configured, the module will attempt to refresh the token once a month automatically.

**Important:** The production_url variable should only be set in the production settings.php file. This prevents development environments from invalidating the production token, as a valid token refresh will invalidate the old one. In other words, you should only enable this feature on ONE site.

## Custom Template Markup

To customize the template markup for displaying Instagram videos, you can use the following HTML snippet as a reference:

```html
<div class="instafeed video"><video poster="{{model.thumbnail_url}}" controls playsinline preload=auto><source src="{{model.media_url}}#t=0.001" type="video/mp4"></video></div>
```

For more information and additional customization options, refer to the [Instafeed.js Templating Documentation](https://github.com/stevenschobert/instafeed.js/wiki/Templating).
